StringTable

Struct StringTable 

pub struct StringTable { /* private fields */ }
Available on crate feature strings only.
A struct for storing strings without duplicates.

Add strings to the table with insert. The returned usize can be used to read the string back from the table’s byte representation.

Use as_bytes to obtain a byte representation of a StringTable. The byte representation is the concatenation of the strings that have been added to the table, with each individual string prefixed with its length in LEB128 encoding. The byte representation contains each string only once.

Example

use watto::StringTable;

let mut table = StringTable::new();
let foo_offset = table.insert("foo");
let bar_offset = table.insert("bar");

let string_bytes = table.as_bytes();
assert_eq!(StringTable::read(string_bytes, foo_offset).unwrap(), "foo");
assert_eq!(StringTable::read(string_bytes, bar_offset).unwrap(), "bar");

Implementations

Source

impl StringTable

pub fn new() -> Self

Initializes an empty StringTable.

pub fn from_bytes(buffer: &[u8]) -> Result<Self, ReadStringError>

Initializes a StringTable from a previously serialized representation.

This essentially reverses the as_bytes call.

pub fn insert(&mut self, s: &str) -> usize

Insert a string into this StringTable.

Returns an offset that can be used to retrieve the inserted string with read after serializing this table with as_bytes.

pub fn as_bytes(&self) -> &[u8]

Returns a byte slice containing the concatenation of the strings that have been added to this StringTable.

pub fn into_bytes(self) -> Vec<u8>

Returns a byte vector containing the concatenation of the strings that have been added to this StringTable.

This consumes the StringTable.

pub fn read(buffer: &[u8], offset: usize) -> Result<&str, ReadStringError>

Returns the string stored at the given offset in the byte slice, if any.

Use this to retrieve a string that was previously inserted into a StringTable.